# Puppet configuration module for Puppet

## Description
Puppet module for managing the configuration of Puppet as both master and slave.

## Example usage

### Puppet Master

	class { 'puppet::master': autosign => true, reports => 'store', }

In addition the `storeconfigs` parameter (default: false) may be supplied.

### Resulting files

#### /etc/puppet/puppet.conf

    # This file is automatically generated by Puppet
    #
    # Any changes made to this file will be lost on the next automated Puppet run!
    
    [main]
    logdir = /var/log/puppet
    pluginsync = true
    
    [master]
    autosign = true
    reports = store
    storeconfigs = false
    
### Puppet Agent

    class { 'puppet::agent': server => "puppet.example.com", }

In addition the `runinterval` parameter (default: '15m') and the `report` parameter (default: true)
may be supplied.

### Resulting files

#### /etc/puppet/puppet.conf

    # This file is automatically generated by Puppet
    #
    # Any changes made to this file will be lost on the next automated Puppet run!
    
    [main]
    logdir = /var/log/puppet
    pluginsync = true
    
    [agent]
    server = puppet.example.com
    runinterval = 15m
    report = true

### Puppet Master & Agent

	class { 'puppet::master': autosign => true, reports => 'store', }
    class { 'puppet::agent': server => "puppet.example.com", }

### Resulting files

#### /etc/puppet/puppet.conf

    # This file is automatically generated by Puppet
    #
    # Any changes made to this file will be lost on the next automated Puppet run!
    
    [main]
    logdir = /var/log/puppet
    pluginsync = true
    
    [master]
    autosign = true
    reports = store
    storeconfigs = false
    
    [agent]
    server = puppet.example.com
    runinterval = 15m
    report = true
